==> blancoNLpackGenerator-0.1.17-src.zip: src/blanco/properties/message/BlancoPropertiesMessage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.properties.message;

/**
 * blancoProperties Iɗp郁bZ[WB
 */
public class BlancoPropertiesMessage {
    /**
     * bZ[WvpeBt@CΉ邽߂̓Iɗp郊\[XohNXB
     */
    protected final BlancoPropertiesMessageResourceBundle fBundle = new BlancoPropertiesMessageResourceBundle();

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRI001]̕擾܂B
     *
     * No.2:
     * [^ꂽt@C[{0}] [.jar]ŏIĂ܂B[.jar]ŏIt@C^ĂB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbpri001(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbpri001]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRI001] " + fBundle.getMbpri001(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP001]̕擾܂B
     *
     * No.5:
     * [ohURI[{0}]BL[ǂݍ: (\)GXP[vɂ炸sɓB: [{1}]]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprp001(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp001]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp001]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP001] " + fBundle.getMbprp001(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP002]̕擾܂B
     *
     * No.6:
     * [ohURI[{0}]B݂͂̃L[[{1}] (t@C[{2}]) java.util.Propertiesǂݍ݂݂܂ null߂Ă܂B݂ java.util.Properties̓e͈ȉ̒ʂłB]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @param arg2 u{2}̒lB
     * @return bZ[WB
     */
    public String getMbprp002(final String arg0, final String arg1, final String arg2) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp002]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg2 == null) {
            throw new IllegalArgumentException("\bh[getMbprp002]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP002] " + fBundle.getMbprp002(arg0, arg1, arg2);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP003]̕擾܂B
     *
     * No.7:
     * [vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(ŏIIȏԂƂē͂ null^悤Ƃ܂B)]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprp003(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP003] " + fBundle.getMbprp003(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP004]̕擾܂B
     *
     * No.8:
     * [ohURI[{0}]BL[̓ǂݍ݂ 0̃L[擾܂B(t@C[{1}]) ̃vpeBt@C͏łȂ̂ƔfďXLbv܂B]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprp004(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP004] " + fBundle.getMbprp004(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR01]̕擾܂B
     *
     * No.12:
     * [ManifestǍ: java.util.jar.Manifest 烁CAgr[g̎擾 (getMainAttributes) Ɏs܂B{0}]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr01(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR01] " + fBundle.getMbprmr01(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR02]̕擾܂B
     *
     * No.13:
     * [ManifestǍ: }jtFXg oh (Bundle-Name Agr[g) 擾邱Ƃł܂łB]
     *
     * @return bZ[WB
     */
    public String getMbprmr02() {
        return "[MBPRMR02] " + fBundle.getMbprmr02();
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR03]̕擾܂B
     *
     * No.14:
     * [ManifestǍ: }jtFXg ohV{ (Bundle-SymbolicName Agr[g) 擾邱Ƃł܂łB]
     *
     * @return bZ[WB
     */
    public String getMbprmr03() {
        return "[MBPRMR03] " + fBundle.getMbprmr03();
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR04]̕擾܂B
     *
     * No.15:
     * [ManifestǍ: }jtFXg oho[W (Bundle-Version Agr[g) 擾邱Ƃł܂łB]
     *
     * @return bZ[WB
     */
    public String getMbprmr04() {
        return "[MBPRMR04] " + fBundle.getMbprmr04();
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR11]̕擾܂B
     *
     * No.16:
     * [ManifestǍ: w肳ꂽvOCfBNg[{0}]݂͑܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr11(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr11]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR11] " + fBundle.getMbprmr11(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR12]̕擾܂B
     *
     * No.17:
     * [ManifestǍ: w肳ꂽvOCfBNg[{0}]́Aۂɂ̓fBNgł͂܂łB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr12(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr12]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR12] " + fBundle.getMbprmr12(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR21]̕擾܂B
     *
     * No.18:
     * [ManifestǍ: w肳ꂽvOCjart@C[{0}]݂͑܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr21(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr21]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR21] " + fBundle.getMbprmr21(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR22]̕擾܂B
     *
     * No.19:
     * [ManifestǍ: w肳ꂽvOCjart@C[{0}]́Aۂɂ̓t@Cł͂܂łB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr22(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr22]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR22] " + fBundle.getMbprmr22(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ01]̕擾܂B
     *
     * No.24:
     * [vOCjart@C: w肳ꂽvOC[gfBNg[{0}]݂͑܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmj01(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ01] " + fBundle.getMbprmj01(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ02]̕擾܂B
     *
     * No.25:
     * [vOCjart@C: w肳ꂽvOC[gfBNg[{0}]͎ۂɂ̓fBNgł͂܂łB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmj02(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ02] " + fBundle.getMbprmj02(arg0);
    }
}

==> blancoNLpackGenerator-0.1.20-src.zip: src/blanco/properties/message/BlancoPropertiesMessage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.properties.message;

/**
 * blancoProperties Iɗp郁bZ[WB
 */
public class BlancoPropertiesMessage {
    /**
     * bZ[WvpeBt@CΉ邽߂̓Iɗp郊\[XohNXB
     */
    protected final BlancoPropertiesMessageResourceBundle fBundle = new BlancoPropertiesMessageResourceBundle();

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRI001]̕擾܂B
     *
     * No.2:
     * [^ꂽt@C[{0}] [.jar]ŏIĂ܂B[.jar]ŏIt@C^ĂB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbpri001(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbpri001]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRI001] " + fBundle.getMbpri001(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP001]̕擾܂B
     *
     * No.5:
     * [ohURI[{0}]BL[ǂݍ: (\)GXP[vɂ炸sɓB: [{1}]]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprp001(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp001]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp001]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP001] " + fBundle.getMbprp001(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP002]̕擾܂B
     *
     * No.6:
     * [ohURI[{0}]B݂͂̃L[[{1}] (t@C[{2}]) java.util.Propertiesǂݍ݂݂܂ null߂Ă܂B݂ java.util.Properties̓e͈ȉ̒ʂłB]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @param arg2 u{2}̒lB
     * @return bZ[WB
     */
    public String getMbprp002(final String arg0, final String arg1, final String arg2) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp002]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg2 == null) {
            throw new IllegalArgumentException("\bh[getMbprp002]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP002] " + fBundle.getMbprp002(arg0, arg1, arg2);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP003]̕擾܂B
     *
     * No.7:
     * [vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(ŏIIȏԂƂē͂ null^悤Ƃ܂B)]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprp003(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP003] " + fBundle.getMbprp003(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRP004]̕擾܂B
     *
     * No.8:
     * [ohURI[{0}]BL[̓ǂݍ݂ 0̃L[擾܂B(t@C[{1}]) ̃vpeBt@C͏łȂ̂ƔfďXLbv܂B]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprp004(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprp004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprp004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRP004] " + fBundle.getMbprp004(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR01]̕擾܂B
     *
     * No.12:
     * [ManifestǍ: java.util.jar.Manifest 烁CAgr[g̎擾 (getMainAttributes) Ɏs܂B{0}]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr01(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR01] " + fBundle.getMbprmr01(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR02]̕擾܂B
     *
     * No.13:
     * [ManifestǍ: }jtFXg oh (Bundle-Name Agr[g) 擾邱Ƃł܂łB]
     *
     * @return bZ[WB
     */
    public String getMbprmr02() {
        return "[MBPRMR02] " + fBundle.getMbprmr02();
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR03]̕擾܂B
     *
     * No.14:
     * [ManifestǍ: }jtFXg ohV{ (Bundle-SymbolicName Agr[g) 擾邱Ƃł܂łB]
     *
     * @return bZ[WB
     */
    public String getMbprmr03() {
        return "[MBPRMR03] " + fBundle.getMbprmr03();
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR04]̕擾܂B
     *
     * No.15:
     * [ManifestǍ: }jtFXg oho[W (Bundle-Version Agr[g) 擾邱Ƃł܂łB]
     *
     * @return bZ[WB
     */
    public String getMbprmr04() {
        return "[MBPRMR04] " + fBundle.getMbprmr04();
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR11]̕擾܂B
     *
     * No.16:
     * [ManifestǍ: w肳ꂽvOCfBNg[{0}]݂͑܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr11(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr11]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR11] " + fBundle.getMbprmr11(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR12]̕擾܂B
     *
     * No.17:
     * [ManifestǍ: w肳ꂽvOCfBNg[{0}]́Aۂɂ̓fBNgł͂܂łB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr12(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr12]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR12] " + fBundle.getMbprmr12(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR21]̕擾܂B
     *
     * No.18:
     * [ManifestǍ: w肳ꂽvOCjart@C[{0}]݂͑܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr21(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr21]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR21] " + fBundle.getMbprmr21(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMR22]̕擾܂B
     *
     * No.19:
     * [ManifestǍ: w肳ꂽvOCjart@C[{0}]́Aۂɂ̓t@Cł͂܂łB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmr22(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmr22]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMR22] " + fBundle.getMbprmr22(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ01]̕擾܂B
     *
     * No.24:
     * [vOCjart@C: w肳ꂽvOC[gfBNg[{0}]݂͑܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmj01(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ01] " + fBundle.getMbprmj01(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ02]̕擾܂B
     *
     * No.25:
     * [vOCjart@C: w肳ꂽvOC[gfBNg[{0}]͎ۂɂ̓fBNgł͂܂łB]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMbprmj02(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ02] " + fBundle.getMbprmj02(arg0);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ11]̕擾܂B
     *
     * No.28:
     * [fBNg[{0}]ɓo͗O܂B: {1}]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprmj11(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj11]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj11]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ11] " + fBundle.getMbprmj11(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ12]̕擾܂B
     *
     * No.29:
     * [fBNg[{0}]ɃZLeBO܂B: {1}]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprmj12(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj12]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj12]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ12] " + fBundle.getMbprmj12(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ13]̕擾܂B
     *
     * No.30:
     * [t@C[{0}]ɓo͗O܂B: {1}]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprmj13(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj13]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj13]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ13] " + fBundle.getMbprmj13(arg0, arg1);
    }

    /**
     * bZ[W`ID[BlancoProperties]AL[[MBPRMJ14]̕擾܂B
     *
     * No.31:
     * [t@C[{0}]ɃZLeBO܂B: {1}]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMbprmj14(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj14]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMbprmj14]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MBPRMJ14] " + fBundle.getMbprmj14(arg0, arg1);
    }
}
